@@ -241,17 +241,10 @@ if ( length(unique(dfrm[,1]))==2 && is.factor(dfrm[,2]) ) {
 	# Compute WOE and information value (IV) from crosstab frequencies
 	woe.dfrm$col.perc.a <- woe.dfrm[,1]/sum(woe.dfrm[,1])
 	woe.dfrm$col.perc.b <- woe.dfrm[,2]/sum(woe.dfrm[,2])
-	# Correct column percents in case of 0 frequencies (in case of no NA skip last row)
-	if ( !anyNA(df[,2]) ) {
-		if ( min(woe.dfrm[-nrow(woe.dfrm),1],na.rm=TRUE)==0 | min(woe.dfrm[-nrow(woe.dfrm),2],na.rm=TRUE)==0 ) {
-			woe.dfrm$col.perc.a[-nrow(woe.dfrm)] <- (woe.dfrm$col.perc.a[-nrow(woe.dfrm)]+0.0001)/sum(woe.dfrm$col.perc.a[-nrow(woe.dfrm)]+0.0001)
-			woe.dfrm$col.perc.b[-nrow(woe.dfrm)] <- (woe.dfrm$col.perc.b[-nrow(woe.dfrm)]+0.0001)/sum(woe.dfrm$col.perc.b[-nrow(woe.dfrm)]+0.0001)	
-		}
-	} else {
-		if ( min(woe.dfrm[,1],na.rm=TRUE)==0 | min(woe.dfrm[,2],na.rm=TRUE)==0 ) {
-			woe.dfrm$col.perc.a <- (woe.dfrm$col.perc.a+0.0001)/sum(woe.dfrm$col.perc.a+0.0001)
-			woe.dfrm$col.perc.b <- (woe.dfrm$col.perc.b+0.0001)/sum(woe.dfrm$col.perc.b+0.0001)	
-		}
+	# Correct column percents in case of 0 frequencies
+	if ( min(woe.dfrm[,1],na.rm=TRUE)==0 | min(woe.dfrm[,2],na.rm=TRUE)==0 ) {
+		woe.dfrm$col.perc.a <- (woe.dfrm$col.perc.a+0.0001)/sum(woe.dfrm$col.perc.a+0.0001)
+		woe.dfrm$col.perc.b <- (woe.dfrm$col.perc.b+0.0001)/sum(woe.dfrm$col.perc.b+0.0001)	
 	}
 
 	# Merge factor levels with frequencies < percentage limit specified above to "misc. level" (associated with pos. and neg. WOE values)
@@ -275,17 +268,10 @@ if ( length(unique(dfrm[,1]))==2 && is.factor(dfrm[,2]) ) {
 	# Compute WOE and information value (IV) from crosstab frequencies
 	woe.dfrm$col.perc.a <- woe.dfrm[,1]/sum(woe.dfrm[,1])
 	woe.dfrm$col.perc.b <- woe.dfrm[,2]/sum(woe.dfrm[,2])
-	# Correct column percents in case of 0 frequencies (in case of no NA skip last row)
-	if ( !anyNA(df[,2]) ) {
-		if ( min(woe.dfrm[-nrow(woe.dfrm),1],na.rm=TRUE)==0 | min(woe.dfrm[-nrow(woe.dfrm),2],na.rm=TRUE)==0 ) {
-			woe.dfrm$col.perc.a[-nrow(woe.dfrm)] <- (woe.dfrm$col.perc.a[-nrow(woe.dfrm)]+0.0001)/sum(woe.dfrm$col.perc.a[-nrow(woe.dfrm)]+0.0001)
-			woe.dfrm$col.perc.b[-nrow(woe.dfrm)] <- (woe.dfrm$col.perc.b[-nrow(woe.dfrm)]+0.0001)/sum(woe.dfrm$col.perc.b[-nrow(woe.dfrm)]+0.0001)	
-		}
-	} else {
-		if ( min(woe.dfrm[,1],na.rm=TRUE)==0 | min(woe.dfrm[,2],na.rm=TRUE)==0 ) {
-			woe.dfrm$col.perc.a <- (woe.dfrm$col.perc.a+0.0001)/sum(woe.dfrm$col.perc.a+0.0001)
-			woe.dfrm$col.perc.b <- (woe.dfrm$col.perc.b+0.0001)/sum(woe.dfrm$col.perc.b+0.0001)	
-		}
+	# Correct column percents in case of 0 frequencies
+	if ( min(woe.dfrm[,1],na.rm=TRUE)==0 | min(woe.dfrm[,2],na.rm=TRUE)==0 ) {
+		woe.dfrm$col.perc.a <- (woe.dfrm$col.perc.a+0.0001)/sum(woe.dfrm$col.perc.a+0.0001)
+		woe.dfrm$col.perc.b <- (woe.dfrm$col.perc.b+0.0001)/sum(woe.dfrm$col.perc.b+0.0001)	
 	}
 	woe.dfrm$woe <- 100*log(woe.dfrm$col.perc.a/woe.dfrm$col.perc.b)
 	woe.dfrm$woe[is.finite(woe.dfrm$woe)==FALSE] <- 0   # convert Inf, -Inf and NaN to 0
@@ -389,18 +375,11 @@ if ( length(unique(dfrm[,1]))==2 && is.factor(dfrm[,2]) ) {
 	woe.dfrm.aggr$col.perc.a <- woe.dfrm.aggr[,2]/sum(woe.dfrm.aggr[,2])
 	woe.dfrm.aggr$col.perc.b <- woe.dfrm.aggr[,3]/sum(woe.dfrm.aggr[,3])
 
-	# Correct column percents in case of 0 frequencies (in case of no NA skip last row)
-	if ( !anyNA(df[,2]) ) {
-		if ( min(woe.dfrm.aggr[-nrow(woe.dfrm.aggr),2],na.rm=TRUE)==0 | min(woe.dfrm.aggr[-nrow(woe.dfrm.aggr),3],na.rm=TRUE)==0 ) {
-			woe.dfrm.aggr$col.perc.a[-nrow(woe.dfrm.aggr)] <- (woe.dfrm.aggr$col.perc.a[-nrow(woe.dfrm.aggr)]+0.0001)/sum(woe.dfrm.aggr$col.perc.a[-nrow(woe.dfrm.aggr)]+0.0001)
-			woe.dfrm.aggr$col.perc.b[-nrow(woe.dfrm.aggr)] <- (woe.dfrm.aggr$col.perc.b[-nrow(woe.dfrm.aggr)]+0.0001)/sum(woe.dfrm.aggr$col.perc.b[-nrow(woe.dfrm.aggr)]+0.0001)	
-		}
-	} else {
-		if ( min(woe.dfrm.aggr[,2],na.rm=TRUE)==0 | min(woe.dfrm.aggr[,3],na.rm=TRUE)==0 ) {
-			woe.dfrm.aggr$col.perc.a <- (woe.dfrm.aggr$col.perc.a+0.0001)/sum(woe.dfrm.aggr$col.perc.a+0.0001)
-			woe.dfrm.aggr$col.perc.b <- (woe.dfrm.aggr$col.perc.b+0.0001)/sum(woe.dfrm.aggr$col.perc.b+0.0001)	
-		}
-	}
+	# Correct column percents in case of 0 frequencies
+	if ( min(woe.dfrm.aggr[,2],na.rm=TRUE)==0 | min(woe.dfrm.aggr[,3],na.rm=TRUE)==0 ) {
+		woe.dfrm.aggr$col.perc.a <- (woe.dfrm.aggr$col.perc.a+0.0001)/sum(woe.dfrm.aggr$col.perc.a+0.0001)
+		woe.dfrm.aggr$col.perc.b <- (woe.dfrm.aggr$col.perc.b+0.0001)/sum(woe.dfrm.aggr$col.perc.b+0.0001)	
+	}	
 	woe.dfrm.aggr$woe <- 100*log(woe.dfrm.aggr$col.perc.a/woe.dfrm.aggr$col.perc.b)
 	woe.dfrm.aggr$woe[is.finite(woe.dfrm.aggr$woe)==FALSE] <- 0   # convert Inf, -Inf and NaN to 0
 	woe.dfrm.aggr <- woe.dfrm.aggr[order(woe.dfrm.aggr$woe),]   # sort data via WOE values
@@ -417,8 +396,14 @@ if ( length(unique(dfrm[,1]))==2 && is.factor(dfrm[,2]) ) {
 	look.up.table$Group.2 <- factor(look.up.table$Group.2)
 	
 	# In case the misc. level consists only of only NA rename it 'Missing'
-	if ( length(which(look.up.table[,2]=='Missing'))==1 && (length(which(look.up.table[,1]=="misc. level neg."))==1 || length(which(look.up.table[,1]=="misc. level pos."))==1) ) {
-		if ( (which(look.up.table[,2]=='Missing') == which(look.up.table[,1]=='misc. level neg.')) || (which(look.up.table[,2]=='Missing') == which(look.up.table[,1]=='misc. level pos.')) ) {
+	if ( length(which(look.up.table[,2]=='Missing'))==1 && length(which(look.up.table[,1]=="misc. level neg."))==1 ) {
+		if ( (which(look.up.table[,2]=='Missing') == which(look.up.table[,1]=='misc. level neg.')) ) {
+			levels(look.up.table[,1]) <- c(levels(look.up.table[,2]), 'Missing')   # add factor level 'Missing'
+			look.up.table[,1][look.up.table[,2]=='Missing'] <- 'Missing'
+		}
+	}
+	if ( length(which(look.up.table[,2]=='Missing'))==1 && length(which(look.up.table[,1]=="misc. level pos."))==1 ) {
+		if ( (which(look.up.table[,2]=='Missing') == which(look.up.table[,1]=='misc. level pos.')) ) {
 			levels(look.up.table[,1]) <- c(levels(look.up.table[,2]), 'Missing')   # add factor level 'Missing'
 			look.up.table[,1][look.up.table[,2]=='Missing'] <- 'Missing'
 		}
